@@ -1,4 +1,4 @@
 mod drawing_area;
 mod window;
 
-pub use window::{View, Window};
+pub use window::Window;
